
from kotonebot.tasks.common import sprite_path
from kotonebot.backend.core import Image, HintBox, HintPoint



class Common:
    
    ButtonClose = Image(path=sprite_path(r"bbb69ecb-6b3b-40ba-8c03-78a485e755a7.png"), name="button_close.png")

    ButtonCommuFastforward = Image(path=sprite_path(r"60907d69-e62f-4653-9359-ae4e1cea6502.png"), name="button_commu_fastforward.png")

    ButtonCommuSkip = Image(path=sprite_path(r"9b3c59e2-f137-40ae-8cd3-36d1b77fd518.png"), name="button_commu_skip.png")

    ButtonCompletion = Image(path=sprite_path(r"65844ab7-9b47-40d1-b96e-e2343f41c3a1.png"), name="button_completion.png")

    ButtonConfirm = Image(path=sprite_path(r"e78b5c6a-f724-4073-ba89-3b3adc210a1b.png"), name="button_confirm.png")

    ButtonConfirmNoIcon = Image(path=sprite_path(r"7595e9ec-4e7f-446c-81b1-859f4294796b.png"), name="button_confirm_no_icon.png")

    ButtonContest = Image(path=sprite_path(r"e49904a9-4f9a-4d5c-a029-a06738f4e5e4.png"), name="button_contest.png")

    ButtonEnd = Image(path=sprite_path(r"a0231cf9-68c8-4304-a188-ede5b51a4910.png"), name="button_end.png")

    ButtonHome = Image(path=sprite_path(r"5a08f8f8-b365-45ce-a549-488a40b78d44.png"), name="button_home.png")

    ButtonIconArrowShort = Image(path=sprite_path(r"11ca01f9-ba56-47ec-b300-bb13be7aa2b1.png"), name="button_icon_arrow_short.png")

    ButtonIconArrowShortDisabled = Image(path=sprite_path(r"c86d05d9-76c1-4417-bbc1-3c85384a9bd2.png"), name="button_icon_arrow_short_disabled.png")

    ButtonIconCheckMark = Image(path=sprite_path(r"99e54d2d-09f0-4e6a-8b4a-15a7173de36d.png"), name="button_icon_check_mark.png")

    ButtonIconClose = Image(path=sprite_path(r"c4ea4126-a392-4720-9ee4-f95fb5a44868.png"), name="button_icon_close.png")

    ButtonIdol = Image(path=sprite_path(r"1f33a300-e0a6-4880-808f-8715a8b4d27c.png"), name="button_idol.png")

    ButtonIdolSupportCard = Image(path=sprite_path(r"b99a98c6-4e7f-4222-afe0-77e8d52f99b1.png"), name="button_idol_support_card.png")

    ButtonNext = Image(path=sprite_path(r"6d2b31d3-d8ac-4b2b-990b-7437d9db3979.png"), name="button_next.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"682e5388-cf9b-449c-8e82-b323980022e6.png"), name="button_next_no_icon.png")

    ButtonRetry = Image(path=sprite_path(r"92ba8040-6749-4691-9c95-315870a75aad.png"), name="button_retry.png")

    ButtonSelect = Image(path=sprite_path(r"5b37c0ef-0a1d-4e4f-986d-8313826e9a5e.png"), name="button_select.png")

    ButtonStart = Image(path=sprite_path(r"913ba636-d771-43ac-ba77-4a7623c5e5c5.png"), name="button_start.png")

    ButtonToolbarHome = Image(path=sprite_path(r"dbc929ab-29ba-444b-b908-4044fd2f288c.png"), name="button_toolbar_home.png")

    CheckboxUnchecked = Image(path=sprite_path(r"5808c98a-2df7-4a29-8719-da8c1a1aa26d.png"), name="checkbox_unchecked.png")

    ButtonToolbarHomeBinary = Image(path=sprite_path(r"2f68e457-4491-4ebc-b436-e3e63db92e14.png"), name="底部工具栏 首页按钮 二值化图片")

    ButtonToolbarMenuBinary = Image(path=sprite_path(r"bf6dcf21-2ffc-441f-82f3-59319f2313b1.png"), name="底部工具栏 菜单按钮 二值化图片")

    TextGameUpdate = Image(path=sprite_path(r"df79be40-e903-4427-a5bf-57d8d5f40991.png"), name="text_game_update.png")

    TextNetworkError = Image(path=sprite_path(r"abf83fc8-5209-456f-a1e8-df78cc33c399.png"), name="text_network_error.png")

    ButtonOK = Image(path=sprite_path(r"8424ecdd-8857-4764-9fd0-d4bfa440c128.png"), name="OK 按钮")

    ButtonSelect2 = Image(path=sprite_path(r"5ebcde3b-f0fd-4e5d-b3de-ada8f0b5e03b.png"), name="選択する")


    pass
class Daily:
    
    ButonLinkData = Image(path=sprite_path(r"c3d430f6-22e6-44b0-b377-d8cfb64eaa8c.png"), name="buton_link_data.png")

    ButtonAssignmentPartial = Image(path=sprite_path(r"a7567472-918f-4a3c-bb33-863d91908642.png"), name="button_assignment_partial.png")

    ButtonClaimAllNoIcon = Image(path=sprite_path(r"6604fec1-ebc3-405a-b392-51d0bbb20221.png"), name="button_claim_all_no_icon.png")

    ButtonClubCollectReward = Image(path=sprite_path(r"f26985a2-01fd-4b7d-8b01-5478219faef8.png"), name="button_club_collect_reward.png")

    ButtonClubSendGift = Image(path=sprite_path(r"94a219f1-6d9b-44e6-9727-e5c5ad7caa76.png"), name="button_club_send_gift.png")

    ButtonClubSendGiftNext = Image(path=sprite_path(r"65b618e2-703f-4c0e-9809-078e02b87de9.png"), name="button_club_send_gift_next.png")

    ButtonContestChallenge = Image(path=sprite_path(r"480429b9-9935-43e6-ab1b-1a535f8e9e89.png"), name="button_contest_challenge.png")

    ButtonContestChallengeStart = Image(path=sprite_path(r"2ac642e5-dc81-4dd1-a1be-914a3d7ac62c.png"), name="button_contest_challenge_start.png")

    ButtonContestRanking = Image(path=sprite_path(r"832d3433-2049-497b-bc37-6f193c1c57e3.png"), name="button_contest_ranking.png")

    ButtonContestStart = Image(path=sprite_path(r"e67a3fb4-dba2-4cae-a841-43fca94a3893.png"), name="button_contest_start.png")

    ButtonDailyShop = Image(path=sprite_path(r"416bfb87-e304-4759-a0fe-aa9b741a7a70.png"), name="button_daily_shop.png")

    ButtonHomeCurrent = Image(path=sprite_path(r"d1240e56-ddfe-40e5-b115-09530b0527cf.png"), name="button_home_current.png")

    ButtonIconPass = Image(path=sprite_path(r"dc7f7ecf-a003-4ad0-bb49-406df5e5b570.png"), name="button_icon_pass.png")

    ButtonIconSkip = Image(path=sprite_path(r"773fb7ad-71fd-4495-a665-d6acd6a7f477.png"), name="button_icon_skip.png")

    ButtonMission = Image(path=sprite_path(r"85ac6b23-84bf-42fe-b801-bf6d7bd92504.png"), name="button_mission.png")

    ButtonPass = Image(path=sprite_path(r"3e2a8c8f-dd9b-4fd1-8117-ed073841973d.png"), name="button_pass.png")

    ButtonPassClaim = Image(path=sprite_path(r"233114c7-23db-425b-8f16-ad8698fa9432.png"), name="button_pass_claim.png")

    ButtonPresentsPartial = Image(path=sprite_path(r"cb7cb4b4-240f-4f5e-b202-a0190120ac81.png"), name="button_presents_partial.png")

    ButtonProduce = Image(path=sprite_path(r"6b472ca5-9035-47af-950c-08d21ec96544.png"), name="button_produce.png")

    ButtonShop = Image(path=sprite_path(r"a875fc2d-fdb6-4375-8db2-786cf58187bc.png"), name="button_shop.png")

    ButtonShopCapsuleToys = Image(path=sprite_path(r"e97d15fc-7f81-4f5e-8cdc-7530f3b6a74f.png"), name="button_shop_capsule_toys.png")

    ButtonShopCapsuleToysDraw = Image(path=sprite_path(r"277fc854-d2e5-46fe-9811-c53ac851df89.png"), name="button_shop_capsule_toys_draw.png")

    ButtonShopCountAdd = Image(path=sprite_path(r"2b435505-1509-4bc9-884c-ecf071550723.png"), name="button_shop_count_add.png")

    ButtonShopCountAddDisabled = Image(path=sprite_path(r"41b30d83-7e3b-490d-a772-b58c291c6e48.png"), name="button_shop_count_add_disabled.png")

    ButtonSupportCardUpgrade = Image(path=sprite_path(r"0217d011-19c5-429b-98dd-1b518d385dce.png"), name="button_support_card_upgrade.png")

    IconTitleDailyShop = Image(path=sprite_path(r"e9ee330d-dfca-440e-8b8c-0a3b4e8c8730.png"), name="日常商店标题图标")

    BoxHomeAssignment = HintBox(x1=16, y1=642, x2=127, y2=752, source_resolution=(720, 1280))

    BoxHomeAP = HintBox(x1=291, y1=4, x2=500, y2=82, source_resolution=(720, 1280))

    BoxHomeJewel = HintBox(x1=500, y1=7, x2=703, y2=82, source_resolution=(720, 1280))

    BoxHomeActivelyFunds = HintBox(x1=11, y1=517, x2=137, y2=637, source_resolution=(720, 1280))

    IconAssignKouchou = Image(path=sprite_path(r"8ca5e65b-92fc-4d01-bb7e-328fcc935e4b.png"), name="icon_assign_kouchou.png")

    IconAssignMiniLive = Image(path=sprite_path(r"e13b5f2a-869d-46ef-8499-2c9c38235991.png"), name="icon_assign_mini_live.png")

    IconAssignOnlineLive = Image(path=sprite_path(r"49c57c36-1982-4dd2-bedd-b5f4baf35c21.png"), name="icon_assign_online_live.png")

    IconAssignTitle = Image(path=sprite_path(r"e596e907-4537-49ff-9b8d-d3027fbec068.png"), name="icon_assign_title.png")

    IconMenu = Image(path=sprite_path(r"c5ae01e9-4174-4cf5-9ed7-cb404bdef805.png"), name="icon_menu.png")

    IconMenuClub = Image(path=sprite_path(r"206edc97-3858-4c9a-9017-4f82b87f1b7e.png"), name="icon_menu_club.png")

    IconShopAp = Image(path=sprite_path(r"5fc7367c-47ea-4cb3-8a12-0f2b369a44b4.png"), name="icon_shop_ap.png")

    IconShopMoney = Image(path=sprite_path(r"53c288b1-d6d6-45e2-887a-825d964fe161.png"), name="icon_shop_money.png")

    IconShopTitle = Image(path=sprite_path(r"ec7bf90d-6d40-433f-a1ae-ff7f4f4820c9.png"), name="icon_shop_title.png")

    IconTitleAssign = Image(path=sprite_path(r"23fcf30e-169c-41e5-bf73-bf775865b5ca.png"), name="icon_title_assign.png")

    IconTitlePass = Image(path=sprite_path(r"af4ccf65-330a-4bbf-a35d-5b45e2a4d1e3.png"), name="icon_title_pass.png")

    BoxApkUpdateDialogTitle = HintBox(x1=26, y1=905, x2=342, y2=967, source_resolution=(720, 1280))

    ButtonAssignmentShortenTime = Image(path=sprite_path(r"1652f06a-5417-49ef-8949-4854772d9ab7.png"), name="工作页面 短缩 时间")

    class Club:
        
        NoteRequestHintBox = HintBox(x1=314, y1=1071, x2=450, y2=1099, source_resolution=(720, 1280))
    
    
        pass
    BoxMissonTabs = HintBox(x1=11, y1=929, x2=703, y2=1030, source_resolution=(720, 1280))

    class CapsuleToys:
        
        NextPageStartPoint = HintPoint(x=360, y=1167)
    
        NextPageEndPoint = HintPoint(x=362, y=267)
    
        IconTitle = Image(path=sprite_path(r"2bd6fe88-99fa-443d-8e42-bb3de5881213.png"), name="日常 扭蛋 页面标题图标")
    
        SliderStartPoint = HintPoint(x=476, y=898)
    
        SliderEndPoint = HintPoint(x=230, y=898)
    
    
        pass
    class SupportCard:
        
        DragDownStartPoint = HintPoint(x=357, y=872)
    
        DragDownEndPoint = HintPoint(x=362, y=194)
    
        TargetSupportCard = HintPoint(x=138, y=432)
    
    
        pass
    TextActivityFundsMax = Image(path=sprite_path(r"ba3d625c-5e7e-40a0-ae3f-e2fc51c90946.png"), name="text_activity_funds_max.png")

    TextAssignmentCompleted = Image(path=sprite_path(r"8737c85b-1802-4b48-bb79-ac7c24a664ce.png"), name="text_assignment_completed.png")

    TextContest = Image(path=sprite_path(r"75d16d64-d6dd-4d8a-a4e6-7d7437d22c3c.png"), name="text_contest.png")

    TextContestLastOngoing = Image(path=sprite_path(r"d41582e9-3574-4494-9b70-f5c878bff465.png"), name="text_contest_last_ongoing.png")

    TextContestNoMemory = Image(path=sprite_path(r"5b0072b1-cb59-4dab-b963-3b552831491b.png"), name="text_contest_no_memory.png")

    TextContestOverallStats = Image(path=sprite_path(r"626c0c57-911b-4a72-86ef-f5897403a886.png"), name="text_contest_overall_stats.png")

    TextShopPurchased = Image(path=sprite_path(r"faf49af8-b3bd-4525-84dc-239ea29d6dee.png"), name="text_shop_purchased.png")

    TextShopRecommended = Image(path=sprite_path(r"5856ecf1-162f-4e0a-840a-e7380b4ee2c1.png"), name="text_shop_recommended.png")

    TextTabShopAp = Image(path=sprite_path(r"04c3742b-5c2f-4bb5-9b26-1d4248f0fc42.png"), name="text_tab_shop_ap.png")


    pass
class Shop:
    
    ItemLessonNote = Image(path=sprite_path(r"0949c622-9067-4f0d-bac2-3f938a1d2ed2.png"), name="レッスンノート")

    ItemVeteranNote = Image(path=sprite_path(r"b2af59e9-60e3-4d97-8c72-c7ba092113a3.png"), name="ベテランノート")

    ItemSupportEnhancementPt = Image(path=sprite_path(r"835489e2-b29b-426c-b4c9-3bb9f8eb6195.png"), name="サポート強化Pt 支援强化Pt")

    ItemSenseNoteVocal = Image(path=sprite_path(r"c5b7d67e-7260-4f08-a0e9-4d31ce9bbecf.png"), name="センスノート（ボーカル）感性笔记（声乐）")

    ItemSenseNoteDance = Image(path=sprite_path(r"0f7d581d-cea3-4039-9205-732e4cd29293.png"), name="センスノート（ダンス）感性笔记（舞蹈）")

    ItemSenseNoteVisual = Image(path=sprite_path(r"d3cc3323-51af-4882-ae12-49e7384b746d.png"), name="センスノート（ビジュアル）感性笔记（形象）")

    ItemLogicNoteVocal = Image(path=sprite_path(r"a1df3af1-a3e7-4521-a085-e4dc3cd1cc57.png"), name="ロジックノート（ボーカル）理性笔记（声乐）")

    ItemLogicNoteDance = Image(path=sprite_path(r"a9fcaf04-0c1f-4b0f-bb5b-ede9da96180f.png"), name="ロジックノート（ダンス）理性笔记（舞蹈）")

    ItemLogicNoteVisual = Image(path=sprite_path(r"c3f536d6-a04a-4651-b3f9-dd2c22593f7f.png"), name="ロジックノート（ビジュアル）理性笔记（形象）")

    ItemAnomalyNoteVocal = Image(path=sprite_path(r"eef25cf9-afd0-43b1-b9c5-fbd997bd5fe0.png"), name="アノマリーノート（ボーカル）非凡笔记（声乐）")

    ItemAnomalyNoteDance = Image(path=sprite_path(r"df991b42-ed8e-4f2c-bf0c-aa7522f147b6.png"), name="アノマリーノート（ダンス）非凡笔记（舞蹈）")

    ItemAnomalyNoteVisual = Image(path=sprite_path(r"9340b854-025c-40da-9387-385d38433bef.png"), name="アノマリーノート（ビジュアル）非凡笔记（形象）")

    ItemRechallengeTicket = Image(path=sprite_path(r"ea1ba124-9cb3-4427-969a-bacd47e7d920.png"), name="再挑戦チケット 重新挑战券")

    ItemRecordKey = Image(path=sprite_path(r"1926f2f9-4bd7-48eb-9eba-28ec4efb0606.png"), name="記録の鍵  解锁交流的物品")

    class IdolPiece:
        
        倉本千奈_WonderScale = Image(path=sprite_path(r"6720b6e8-ae80-4cc0-a885-518efe12b707.png"), name="倉本千奈 WonderScale 碎片")
    
        篠泽广_光景 = Image(path=sprite_path(r"afa06fdc-a345-4384-b25d-b16540830256.png"), name="篠泽广 光景 碎片")
    
        紫云清夏_TameLieOneStep = Image(path=sprite_path(r"278b7d9c-707e-4392-9677-74574b5cdf42.png"), name="紫云清夏 Tame-Lie-One-Step 碎片")
    
        葛城リーリヤ_白線 = Image(path=sprite_path(r"74ff07b3-d91c-4579-80cd-379ed7020622.png"), name="葛城リーリヤ 白線 碎片")
    
        姫崎薪波_cIclumsy_trick  = Image(path=sprite_path(r"a7f5abf1-982f-4a55-8d41-3ad6f56798e0.png"), name="姫崎薪波 cIclumsy trick 碎片")
    
        花海咲季_FightingMyWay = Image(path=sprite_path(r"2bc00520-0afe-40e5-8743-d33fc6b2945a.png"), name="花海咲季 FightingMyWay 碎片")
    
        藤田ことね_世界一可愛い私 = Image(path=sprite_path(r"135ee57a-d30d-4ba8-83f0-9f1681a49ff7.png"), name="藤田ことね 世界一可愛い私 碎片")
    
        花海佑芽_TheRollingRiceball = Image(path=sprite_path(r"d15959bf-d07b-4f07-948a-c0aeaf17756a.png"), name="花海佑芽 The Rolling Riceball 碎片")
    
        月村手毬_LunaSayMaybe = Image(path=sprite_path(r"868b97a9-492e-4712-b47f-82b97495b019.png"), name="月村手毬 Luna say maybe 碎片")
    
    
        pass

    pass
class Produce:
    
    BoxProduceOngoing = HintBox(x1=179, y1=937, x2=551, y2=1091, source_resolution=(720, 1280))

    ButtonAutoSet = Image(path=sprite_path(r"0aa6f693-4500-46a5-b713-32d865418ce8.png"), name="button_auto_set.png")

    ButtonProduce = Image(path=sprite_path(r"e99bc144-202c-457e-8f4f-609e8b5f6793.png"), name="button_produce.png")

    ButtonProduceStart = Image(path=sprite_path(r"54ccb7af-46e7-4096-9fc6-4593cc62f6e6.png"), name="button_produce_start.png")

    ButtonRegular = Image(path=sprite_path(r"3d0e5063-f05f-48a8-82e0-484cfeaa76a3.png"), name="button_regular.png")

    CheckboxIconNoteBoost = Image(path=sprite_path(r"1579c223-d9c0-43a2-af52-6d61a601b7cc.png"), name="checkbox_icon_note_boost.png")

    CheckboxIconSupportPtBoost = Image(path=sprite_path(r"012328ef-6300-4217-b02a-81798ade0f6d.png"), name="checkbox_icon_support_pt_boost.png")

    BoxModeButtons = HintBox(x1=7, y1=818, x2=713, y2=996, source_resolution=(720, 1280))

    ButtonPIdolOverview = Image(path=sprite_path(r"e88c9ad1-ec37-4fcd-b086-862e1e7ce8fd.png"), name="Pアイドルー覧  P偶像列表展示")

    BoxStepIndicator = HintBox(x1=4, y1=11, x2=405, y2=99, source_resolution=(720, 1280))

    BoxSetCountIndicator = HintBox(x1=17, y1=671, x2=119, y2=707, source_resolution=(720, 1280))

    PointProduceNextSet = HintPoint(x=702, y=832)

    PointProducePrevSet = HintPoint(x=14, y=832)

    IconPIdolLevel = Image(path=sprite_path(r"30a6f399-6999-4f04-bb77-651e0214112f.png"), name="P偶像卡上的等级图标")

    KbIdolOverviewName = HintBox(x1=140, y1=16, x2=615, y2=97, source_resolution=(720, 1280))

    ButtonResume = Image(path=sprite_path(r"ccbcb114-7f73-43d1-904a-3a7ae660c531.png"), name="再開する")

    BoxResumeDialogProduceType = HintBox(x1=186, y1=491, x2=541, y2=550, source_resolution=(720, 1280))

    BoxResumeDialogIdolTitle = HintBox(x1=194, y1=794, x2=523, y2=840, source_resolution=(720, 1280))

    RadioTextSkipCommu = Image(path=sprite_path(r"aa25d302-6196-468d-b74b-0aa54e40952c.png"), name="radio_text_skip_commu.png")

    TextAPInsufficient = Image(path=sprite_path(r"4883c564-f950-4a29-9f5f-6f924123cd22.png"), name="培育 AP 不足提示弹窗 标题")

    ButtonRefillAP = Image(path=sprite_path(r"eaba6ebe-f0df-4918-aee5-ef4e3ffedcf0.png"), name="确认恢复AP按钮")

    ScreenshotNoEnoughAp2 = Image(path=sprite_path(r"a1f365b9-ca54-462a-91d2-dd916f5f88ad.png"), name="screenshot_no_enough_ap_2.png")

    TextRentAvailable = Image(path=sprite_path(r"ab131ea1-c5da-467e-a227-9ba2aa3a98bd.png"), name="text_rent_available.png")


    pass
class InPurodyuusu:
    
    A = Image(path=sprite_path(r"68c62394-52ac-4005-a3b0-23bcc2710641.png"), name="A.png")

    AcquireBtnDisabled = Image(path=sprite_path(r"7489c3c5-a02b-48ad-9599-b94cd3c92d59.png"), name="acquire_btn_disabled.png")

    ButtonCancel = Image(path=sprite_path(r"3af5deff-6c52-40e4-a788-1400e3264dfe.png"), name="button_cancel.png")

    ButtonComplete = Image(path=sprite_path(r"435de14f-a86b-4d42-af00-19d2991d8808.png"), name="button_complete.png")

    ButtonFinalPracticeDance = Image(path=sprite_path(r"9c57cf5e-d7eb-4900-a77d-29b034f4cd5e.png"), name="button_final_practice_dance.png")

    ButtonFinalPracticeVisual = Image(path=sprite_path(r"802fc6ca-6932-4b35-b3ac-589032f415a2.png"), name="button_final_practice_visual.png")

    ButtonFinalPracticeVocal = Image(path=sprite_path(r"80f69421-c156-40cf-aa9c-00291beb42a6.png"), name="button_final_practice_vocal.png")

    ButtonFollowNoIcon = Image(path=sprite_path(r"09b99e48-ccd4-4bcf-be3a-ac7e41f071e8.png"), name="button_follow_no_icon.png")

    ButtonIconStudy = Image(path=sprite_path(r"083a1069-a36a-402a-af17-01fa7001c5d5.png"), name="button_icon_study.png")

    ButtonIconStudyVisual = Image(path=sprite_path(r"80647a5f-d406-4c04-9d10-9d411ed4fd10.png"), name="button_icon_study_visual.png")

    ButtonLeave = Image(path=sprite_path(r"f56d9139-ba97-43ee-848f-9977d9cbcfc6.png"), name="button_leave.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"5b44d293-cd1d-4ad0-bbc8-7a8179075a6e.png"), name="button_next_no_icon.png")

    ButtonNotAcquire = Image(path=sprite_path(r"e7e65e74-ff0d-40dc-b87c-5d21dd53d431.png"), name="button_not_acquire.png")

    ButtonRetry = Image(path=sprite_path(r"62d6caa6-d3e0-4ffa-b753-c07b07156158.png"), name="button_retry.png")

    ButtonTextActionOuting = Image(path=sprite_path(r"4592feac-9d28-42c7-802e-a45b93295490.png"), name="button_text_action_outing.png")

    ButtonTextAllowance = Image(path=sprite_path(r"a12a99ba-e490-455c-b1a7-7e2ed62e009d.png"), name="button_text_allowance.png")

    ButtonTextConsult = Image(path=sprite_path(r"47aa6549-6ded-416c-a4e3-e7f127196fb1.png"), name="button_text_consult.png")

    IconClearBlue = Image(path=sprite_path(r"c023f806-806d-41a3-952f-9ea27d055c3f.png"), name="icon_clear_blue.png")

    IconTitleAllowance = Image(path=sprite_path(r"cfbbf168-66fb-4e9c-91c1-1dec62e1f736.png"), name="icon_title_allowance.png")

    IconTitleStudy = Image(path=sprite_path(r"90359f53-b42e-42ab-871d-7f502c692240.png"), name="icon_title_study.png")

    LootboxSliverLock = Image(path=sprite_path(r"534826a9-baeb-486c-b4ba-31ba6932bf99.png"), name="lootbox_sliver_lock.png")

    LootBoxSkillCard = Image(path=sprite_path(r"15a9b9f9-cfc6-447d-b763-adb5d7ca56fb.png"), name="loot_box_skill_card.png")

    M = Image(path=sprite_path(r"7e5e9eac-f060-4228-9b2a-86ec59e8aa58.png"), name="M.png")

    BoxWeeksUntilExam = HintBox(x1=11, y1=8, x2=237, y2=196, source_resolution=(720, 1280))

    TextActionVocal = Image(path=sprite_path(r"d6b64759-26b7-45b1-bf8e-5c0d98611e0d.png"), name="Vo. レッスン")

    TextActionDance = Image(path=sprite_path(r"303cccc1-c674-4d3a-8c89-19ea729fdbef.png"), name="Da. レッスン")

    TextActionVisual = Image(path=sprite_path(r"cc8a495d-330d-447d-8a80-a8a6ecc409c5.png"), name="Vi. レッスン")

    BoxExamTop = HintBox(x1=5, y1=2, x2=712, y2=55, source_resolution=(720, 1280))

    PDrinkIcon = Image(path=sprite_path(r"71c81d8b-33ec-4d1f-8b1d-56fba276ec5a.png"), name="p_drink_icon.png")

    PItemIconColorful = Image(path=sprite_path(r"de9d0dbd-684d-4eae-96f9-5887b9aaffab.png"), name="p_item_icon_colorful.png")

    PSkillCardIconBlue = Image(path=sprite_path(r"550a13cf-318e-4485-8393-c2934e46eed5.png"), name="p_skill_card_icon_blue.png")

    PSkillCardIconColorful = Image(path=sprite_path(r"5314ff2a-2f28-4a9c-919b-9d889de7efe1.png"), name="p_skill_card_icon_colorful.png")

    Rest = Image(path=sprite_path(r"d409bc0c-dbda-47ec-9d1c-dbdfc926fb7d.png"), name="rest.png")

    RestConfirmBtn = Image(path=sprite_path(r"2b8a798f-8d2f-4488-b44c-aa4a4043e365.png"), name="rest_confirm_btn.png")

    ButtonIconOuting = Image(path=sprite_path(r"8ded6c98-85ea-4858-a66d-4fc8caecb7c5.png"), name="行动按钮图标 外出（おでかけ）")

    BoxGoalClearNext = HintBox(x1=79, y1=503, x2=157, y2=532, source_resolution=(720, 1280))

    BoxLessonCards5_1 = HintBox(x1=16, y1=882, x2=208, y2=1136, source_resolution=(720, 1280))

    BoxNoSkillCard = HintBox(x1=180, y1=977, x2=529, y2=1026, source_resolution=(720, 1280))

    TitleIconOuting = Image(path=sprite_path(r"ee4e512b-4982-49b6-9c71-31984b58e1d0.png"), name="外出（おでかけ）页面 标题图标")

    BoxPDrinkMaxConfirmTitle = HintBox(x1=46, y1=829, x2=270, y2=876, source_resolution=(720, 1280))

    BoxSelectPStuff = HintBox(x1=62, y1=558, x2=655, y2=716, source_resolution=(720, 1280))

    BoxSelectPStuffComfirm = HintBox(x1=256, y1=1064, x2=478, y2=1128, source_resolution=(720, 1280))

    BoxSkillCardAcquired = HintBox(x1=194, y1=712, x2=528, y2=765, source_resolution=(720, 1280))

    BoxSkillCardEnhaced = HintBox(x1=49, y1=948, x2=676, y2=1106, source_resolution=(720, 1280))

    ScreenshotSkillCardEnhanceDialog = Image(path=sprite_path(r"e3bc8982-9a71-40fe-86fb-b39bc525e834.png"), name="screenshot_skill_card_enhance_dialog.png")

    IconTitleSkillCardEnhance = Image(path=sprite_path(r"79abd239-5eed-4195-9fa8-d729daa874ca.png"), name="技能卡强化 标题 图标")

    ButtonEnhance = Image(path=sprite_path(r"da439e8c-3b74-4371-9657-0736d826c7d1.png"), name="技能卡 强化按钮")

    T = Image(path=sprite_path(r"16fbc93d-b294-4001-b4e9-ee2af181415f.png"), name="睡意卡字母 T（眠気）")

    IconSp = Image(path=sprite_path(r"d982d2b5-4bc0-4ae9-a516-f29c2848d64b.png"), name="SP 课程图标")

    BoxCommuEventButtonsArea = HintBox(x1=14, y1=412, x2=703, y2=1089, source_resolution=(720, 1280))

    TextSelfStudyVocal = Image(path=sprite_path(r"c78c38cc-7b61-4dc4-820d-0a5b684ef52e.png"), name="文化课事件 自习 声乐")

    TextSelfStudyDance = Image(path=sprite_path(r"83d0a033-466c-463a-bb8c-be0f2953e9b2.png"), name="文化课事件 自习 舞蹈")

    TextSelfStudyVisual = Image(path=sprite_path(r"4695f96b-c4f5-4bb6-a021-a13b6ceb2883.png"), name="文化课事件 自习 形象")

    TextAsariProduceEnd = Image(path=sprite_path(r"fb8f7719-2608-412f-bb68-ec06b5b68fc9.png"), name="text_asari_produce_end.png")

    TextButtonExamSkipTurn = Image(path=sprite_path(r"40bda10e-8490-4c15-9af1-596995e3c521.png"), name="text_button_exam_skip_turn.png")

    TextClearUntil = Image(path=sprite_path(r"434806a5-5f97-41e8-a6de-62b4be46b6e9.png"), name="text_clear_until.png")

    TextDance = Image(path=sprite_path(r"06403da9-39e6-4300-bee2-1bd9598a501f.png"), name="text_dance.png")

    TextFinalProduceRating = Image(path=sprite_path(r"b8f9b470-4dfb-43ea-abce-3ee7844d072c.png"), name="text_final_produce_rating.png")

    TextOneWeekRemaining = Image(path=sprite_path(r"f444cb04-fd2d-433d-8ae0-233c6223bb1d.png"), name="text_one_week_remaining.png")

    TextPerfectUntil = Image(path=sprite_path(r"94b51b9a-f75c-4093-a344-391f1e11ac82.png"), name="text_perfect_until.png")

    TextPleaseSelectPDrink = Image(path=sprite_path(r"f4d5f0d9-d26c-4a9c-b9d4-5b4008004c96.png"), name="text_please_select_p_drink.png")

    TextPDiary = Image(path=sprite_path(r"92912f2a-a188-4ff8-bbe0-25248ac2f1e2.png"), name="text_p_diary.png")

    TextPDrinkMax = Image(path=sprite_path(r"c821bdab-0884-4a76-9135-1d24de74173a.png"), name="text_p_drink_max.png")

    TextSenseiTipConsult = Image(path=sprite_path(r"3d594ebf-9ba7-4a76-80d3-ccc6d0d7b091.png"), name="text_sensei_tip_consult.png")

    TextSenseiTipDance = Image(path=sprite_path(r"4dec1057-4001-4f6a-91dd-77c291528c25.png"), name="text_sensei_tip_dance.png")

    TextSenseiTipRest = Image(path=sprite_path(r"65f68d36-d757-4eaf-8ec0-74f74de82a89.png"), name="text_sensei_tip_rest.png")

    TextSenseiTipVisual = Image(path=sprite_path(r"2129230d-40d9-40da-a1d0-9556fdcd2285.png"), name="text_sensei_tip_visual.png")

    TextSenseiTipVocal = Image(path=sprite_path(r"53266a37-09b9-4242-8263-2eb3453b9be2.png"), name="text_sensei_tip_vocal.png")

    TextSkipTurnDialog = Image(path=sprite_path(r"eb45056f-883a-41d8-83cc-92a70aa9e113.png"), name="text_skip_turn_dialog.png")

    TextVisual = Image(path=sprite_path(r"68306b80-8e73-4f5e-b440-fc5f39bc530a.png"), name="text_visual.png")

    class Action:
        
        ActionStudy = Image(path=sprite_path(r"cd06fc68-014a-4a9a-a594-602ff06682bf.png"), name="action_study.png")
    
        PDorinkuBg = Image(path=sprite_path(r"06a77039-422c-4c36-9bb6-3d5a2117298c.png"), name="p_dorinku_bg.png")
    
        PDorinkuBgMask = Image(path=sprite_path(r"db7f44b6-af28-4958-a95f-94eb27b2a25a.png"), name="p_dorinku_bg_mask.png")
    
        PItem = Image(path=sprite_path(r"246a0b7c-ae0d-43e1-a074-75bced09d160.png"), name="p_item.png")
    
        VocalWhiteBg = Image(path=sprite_path(r"fe0f10e8-5233-4e26-8783-447d3feea8d3.png"), name="vocal_white_bg.png")
    
    
        pass

    pass
class Kuyo:
    
    ButtonStartGame = Image(path=sprite_path(r"123c9661-6512-4f32-9e05-6705e1c65940.png"), name="button_start_game.png")

    ButtonTab3Speedup = Image(path=sprite_path(r"12c2a56a-cd63-4e5d-89c5-9899091c97d1.png"), name="button_tab3_speedup.png")


    pass


"""启动游戏，领取登录奖励，直到首页为止"""
import logging

from kotonebot import task, device, image, AdaptiveWait, sleep, ocr
from kotonebot.errors import GameUpdateNeededError
from . import R
from .common import Priority, conf
from .actions.loading import loading
from .actions.scenes import at_home, goto_home
from .actions.commu import handle_unread_commu

logger = logging.getLogger(__name__)

@task('启动游戏', priority=Priority.START_GAME)
def start_game():
    """
    启动游戏，直到游戏进入首页为止。
    """

    if not conf().start_game.enabled:
        logger.info('"Start game" is disabled.')
        return
    
    # 如果已经在游戏中，直接返回home
    if device.current_package() == conf().start_game.game_package_name:
        logger.info("Game already started")
        if not at_home():
            logger.info("Not at home, going to home")
            goto_home()
        return
    
    # 如果不在游戏中，启动游戏
    if not conf().start_game.start_through_kuyo:
        # 直接启动
        device.launch_app('com.bandainamcoent.idolmaster_gakuen')
    else:
        # 通过Kuyo启动
        if device.current_package() == conf().start_game.kuyo_package_name:
            logger.warning("Kuyo already started. Auto start game failed.")
            # TODO: Kuyo支持改进
            return
        # 启动kuyo
        device.launch_app('org.kuyo.game')
        # 点击"加速"
        device.click(image.expect_wait(R.Kuyo.ButtonTab3Speedup, timeout=10))
        # 点击"K空间启动"
        device.click(image.expect_wait(R.Kuyo.ButtonStartGame, timeout=10))

    # [screenshots/startup/1.png]
    image.wait_for(R.Daily.ButonLinkData, timeout=30)
    sleep(2)
    device.click_center()
    wait = AdaptiveWait(timeout=240, timeout_message='Game startup loading timeout')
    while True:
        while loading():
            wait()
        with device.pinned():
            if image.find(R.Daily.ButtonHomeCurrent):
                break
            # [screenshots/startup/update.png]
            elif image.find(R.Common.TextGameUpdate):
                device.click(image.expect(R.Common.ButtonConfirm))
            # [kotonebot-resource/sprites/jp/daily/screenshot_apk_update.png]
            elif ocr.find('アップデート', rect=R.Daily.BoxApkUpdateDialogTitle):
                raise GameUpdateNeededError()
            # [screenshots/startup/announcement1.png]
            elif image.find(R.Common.ButtonIconClose):
                device.click()
            # [screenshots/startup/birthday.png]
            elif handle_unread_commu():
                pass
            else:
                device.click_center()
            wait()

if __name__ == '__main__':
    import logging
    logging.basicConfig(level=logging.INFO, format='[%(asctime)s] [%(levelname)s] [%(name)s] [%(funcName)s] [%(lineno)d] %(message)s')
    logger.setLevel(logging.DEBUG)
    start_game()

